@@ -2,7 +2,8 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -20,7 +21,7 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
  */
 
 
@@ -87,15 +88,6 @@
 /* Define if your memcmp is broken.  */
 #undef NO_MEMCMP
 
-/* Define to `long' if <stddef.h> doesn't define.  */
-#undef ptrdiff_t
-
-/* The number of bytes in a ptrdiff_t.  */
-#undef SIZEOF_PTRDIFF_T
-
-/* The number of bytes in a size_t.  */
-#undef SIZEOF_SIZE_T
-
 
 
 /* Leave that blank line there!!  Autoheader needs it.
@@ -109,6 +101,10 @@
 
 /* $BOTTOM$ */
 
+#ifdef __cplusplus
+#  undef /**/ const
+#endif
+
 #if defined(HAVE_SYS_RESOURCE_H) && !defined(TIME_WITH_SYS_TIME)
 #  undef /**/ HAVE_SYS_RESOURCE_H
 #endif
