@@ -2,7 +2,8 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -20,7 +21,7 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
  */
 
 
@@ -53,7 +54,7 @@ static lzo_uint opt_overhead = 0;	/* assume worst case */
 /* used for test purposes only */
 LZO_EXTERN_CDECL(int)
 lzo1x_decompress_asm_fast ( const lzo_byte *src, lzo_uint  src_len,
-                                  lzo_byte *dst, lzo_uint *dst_len,
+                                  lzo_byte *dst, lzo_uintp dst_len,
                                   lzo_voidp wrkmem /* NOT USED */ )
                            __asm__("_lzo1x_decompress_asm_fast");
 #endif
@@ -73,7 +74,7 @@ static lzo_byte *xmalloc(lzo_uint len)
 {
 	lzo_byte *p;
 
-	p = lzo_malloc(len > 0 ? len : 1);
+	p = (lzo_bytep) lzo_malloc(len > 0 ? len : 1);
 	if (p == NULL)
 	{
 		printf("%s: out of memory\n", progname);
@@ -282,7 +283,7 @@ int main(int argc, char *argv[])
 
 	printf("\nLZO real-time data compression library (v%s, %s).\n",
 	        lzo_version_string(), lzo_version_date());
-	printf("Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer\n\n");
+	printf("Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer\n\n");
 
 	progname = argv[0];
 	if (i < argc && argv[i][0] == '-')
@@ -290,7 +291,7 @@ int main(int argc, char *argv[])
 #if 1
 	if (opt_overhead != 0 && opt_overhead < 8)
 	{
-		printf("%s: invalid overhead value %d\n", progname, opt_overhead);
+		printf("%s: invalid overhead value %ld\n", progname, (long)opt_overhead);
 		exit(1);
 	}
 #endif
