@@ -2,7 +2,8 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -20,7 +21,7 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
  */
 
 
@@ -76,7 +77,7 @@ int main(int argc, char *argv[])
 
 	printf("\nLZO real-time data compression library (v%s, %s).\n",
 	        lzo_version_string(), lzo_version_date());
-	printf("Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer\n\n");
+	printf("Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer\n\n");
 
 /*
  * Step 1: initialize the LZO library
@@ -90,9 +91,9 @@ int main(int argc, char *argv[])
 /*
  * Step 2: allocate blocks and the work-memory
  */
-	in = lzo_malloc(IN_LEN);
-	out = lzo_malloc(OUT_LEN);
-	wrkmem = lzo_malloc(LZO1X_1_MEM_COMPRESS);
+	in = (lzo_bytep) lzo_malloc(IN_LEN);
+	out = (lzo_bytep) lzo_malloc(OUT_LEN);
+	wrkmem = (lzo_bytep) lzo_malloc(LZO1X_1_MEM_COMPRESS);
 	if (in == NULL || out == NULL || wrkmem == NULL)
 	{
 		printf("out of memory\n");
