@@ -1,8 +1,9 @@
-/* asm.h -- library assembler functions
+/* asm.h -- library assembler function prototypes
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -20,7 +21,7 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
  */
 
 
@@ -31,7 +32,7 @@
 
 #if !defined(LZO_ASM_NAME)
 #  if defined(__GNUC__)
-#    define LZO_ASM_NAME(x)	__asm__("_" ## #x)
+#    define LZO_ASM_NAME(x)	__asm__("_" #x)
 #  else
 #    define LZO_ASM_NAME(x)
 #  endif
@@ -55,6 +56,7 @@
 **************************************************************************/
 
 #if 1
+   /* LZO1B is not yet implemented in assembly */
 #  define lzo1b_decompress_asm				0
 #  define lzo1b_decompress_asm_safe			0
 #  define lzo1b_decompress_asm_fast			0
@@ -66,13 +68,13 @@
 LZO_EXTERN_CDECL(int)
 lzo1c_decompress_asm
                         ( const lzo_byte *src, lzo_uint  src_len,
-                                lzo_byte *dst, lzo_uint *dst_len,
+                                lzo_byte *dst, lzo_uintp dst_len,
                                 lzo_voidp wrkmem /* NOT USED */ )
                         LZO_ASM_NAME(lzo1c_decompress_asm);
 LZO_EXTERN_CDECL(int)
 lzo1c_decompress_asm_safe
                         ( const lzo_byte *src, lzo_uint  src_len,
-                                lzo_byte *dst, lzo_uint *dst_len,
+                                lzo_byte *dst, lzo_uintp dst_len,
                                 lzo_voidp wrkmem /* NOT USED */ )
                         LZO_ASM_NAME(lzo1c_decompress_asm_safe);
 #  define lzo1c_decompress_asm_fast			0
@@ -91,13 +93,13 @@ lzo1c_decompress_asm_safe
 LZO_EXTERN_CDECL(int)
 lzo1f_decompress_asm_fast
                         ( const lzo_byte *src, lzo_uint  src_len,
-                                lzo_byte *dst, lzo_uint *dst_len,
+                                lzo_byte *dst, lzo_uintp dst_len,
                                 lzo_voidp wrkmem /* NOT USED */ )
                         LZO_ASM_NAME(lzo1f_decompress_asm_fast);
 LZO_EXTERN_CDECL(int)
 lzo1f_decompress_asm_fast_safe
                          (const lzo_byte *src, lzo_uint  src_len,
-                                lzo_byte *dst, lzo_uint *dst_len,
+                                lzo_byte *dst, lzo_uintp dst_len,
                                 lzo_voidp wrkmem /* NOT USED */ )
                         LZO_ASM_NAME(lzo1f_decompress_asm_fast_safe);
 #else
@@ -111,25 +113,25 @@ lzo1f_decompress_asm_fast_safe
 #if defined(LZO1X_HAVE_i386_DECOMPRESS_ASM)
 LZO_EXTERN_CDECL(int)
 lzo1x_decompress_asm    ( const lzo_byte *src, lzo_uint  src_len,
-                                lzo_byte *dst, lzo_uint *dst_len,
+                                lzo_byte *dst, lzo_uintp dst_len,
                                 lzo_voidp wrkmem /* NOT USED */ )
                         LZO_ASM_NAME(lzo1x_decompress_asm);
 LZO_EXTERN_CDECL(int)
 lzo1x_decompress_asm_safe
                         ( const lzo_byte *src, lzo_uint  src_len,
-                                lzo_byte *dst, lzo_uint *dst_len,
+                                lzo_byte *dst, lzo_uintp dst_len,
                                 lzo_voidp wrkmem /* NOT USED */ )
                         LZO_ASM_NAME(lzo1x_decompress_asm_safe);
 LZO_EXTERN_CDECL(int)
 lzo1x_decompress_asm_fast
                         ( const lzo_byte *src, lzo_uint  src_len,
-                                lzo_byte *dst, lzo_uint *dst_len,
+                                lzo_byte *dst, lzo_uintp dst_len,
                                 lzo_voidp wrkmem /* NOT USED */ )
                         LZO_ASM_NAME(lzo1x_decompress_asm_fast);
 LZO_EXTERN_CDECL(int)
 lzo1x_decompress_asm_fast_safe
                          (const lzo_byte *src, lzo_uint  src_len,
-                                lzo_byte *dst, lzo_uint *dst_len,
+                                lzo_byte *dst, lzo_uintp dst_len,
                                 lzo_voidp wrkmem /* NOT USED */ )
                         LZO_ASM_NAME(lzo1x_decompress_asm_fast_safe);
 #else
@@ -143,25 +145,25 @@ lzo1x_decompress_asm_fast_safe
 #if defined(LZO1Y_HAVE_i386_DECOMPRESS_ASM)
 LZO_EXTERN_CDECL(int)
 lzo1y_decompress_asm    ( const lzo_byte *src, lzo_uint  src_len,
-                                lzo_byte *dst, lzo_uint *dst_len,
+                                lzo_byte *dst, lzo_uintp dst_len,
                                 lzo_voidp wrkmem /* NOT USED */ )
                         LZO_ASM_NAME(lzo1y_decompress_asm);
 LZO_EXTERN_CDECL(int)
 lzo1y_decompress_asm_safe
                         ( const lzo_byte *src, lzo_uint  src_len,
-                                lzo_byte *dst, lzo_uint *dst_len,
+                                lzo_byte *dst, lzo_uintp dst_len,
                                 lzo_voidp wrkmem /* NOT USED */ )
                         LZO_ASM_NAME(lzo1y_decompress_asm_safe);
 LZO_EXTERN_CDECL(int)
 lzo1y_decompress_asm_fast
                         ( const lzo_byte *src, lzo_uint  src_len,
-                                lzo_byte *dst, lzo_uint *dst_len,
+                                lzo_byte *dst, lzo_uintp dst_len,
                                 lzo_voidp wrkmem /* NOT USED */ )
                         LZO_ASM_NAME(lzo1y_decompress_asm_fast);
 LZO_EXTERN_CDECL(int)
 lzo1y_decompress_asm_fast_safe
                          (const lzo_byte *src, lzo_uint  src_len,
-                                lzo_byte *dst, lzo_uint *dst_len,
+                                lzo_byte *dst, lzo_uintp dst_len,
                                 lzo_voidp wrkmem /* NOT USED */ )
                         LZO_ASM_NAME(lzo1y_decompress_asm_fast_safe);
 #else
@@ -173,6 +175,6 @@ lzo1y_decompress_asm_fast_safe
 
 
 /*
-vi:ts=4
+vi:ts=4:et
 */
 
