@@ -31,7 +31,7 @@ const lzo_compress_t LZO_COMPRESS_FUNC = do_compress;
 
 LZO_PUBLIC(int)
 LZO_COMPRESS ( const lzo_byte *in,  lzo_uint  in_len,
-                     lzo_byte *out, lzo_uint *out_len,
+                     lzo_byte *out, lzo_uintp out_len,
                      lzo_voidp wrkmem )
 {
 #if defined(__LZO_QUERY_COMPRESS)
@@ -43,5 +43,5 @@ LZO_COMPRESS ( const lzo_byte *in,  lzo_uint  in_len,
 }
 
 /*
-vi:ts=4
+vi:ts=4:et
 */
