@@ -2,7 +2,8 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -20,7 +21,7 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
  */
 
 
@@ -62,13 +63,13 @@
 
 /* check configuration */
 #if (RBITS < 4 || RBITS > 5)
-#  error invalid RBITS
+#  error "invalid RBITS"
 #endif
 #if (DDBITS < 0 || DDBITS > 6)
-#  error invalid DDBITS
+#  error "invalid DDBITS"
 #endif
 #if (CLEVEL < 1 || CLEVEL > 9)
-#  error invalid CLEVEL
+#  error "invalid CLEVEL"
 #endif
 
 
@@ -126,6 +127,6 @@
 #endif /* already included */
 
 /*
-vi:ts=4
+vi:ts=4:et
 */
 
