@@ -2,7 +2,8 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -20,7 +21,7 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
  */
 
 
@@ -59,10 +60,10 @@
 
 /* check configuration */
 #if (RBITS < 3 || RBITS > 5)
-#  error invalid RBITS
+#  error "invalid RBITS"
 #endif
 #if (CLEVEL < 1 || CLEVEL > 9)
-#  error invalid CLEVEL
+#  error "invalid CLEVEL"
 #endif
 
 
@@ -89,7 +90,7 @@
 
 /* check other constants */
 #if (LBITS < 5 || LBITS > 8)
-#  error invalid LBITS
+#  error "invalid LBITS"
 #endif
 
 
@@ -125,7 +126,7 @@ lzo1a_info ( int *rbits, int *clevel )
 
 LZO_PUBLIC(int)
 lzo1a_decompress ( const lzo_byte *in , lzo_uint  in_len,
-                         lzo_byte *out, lzo_uint *out_len,
+                         lzo_byte *out, lzo_uintp out_len,
                          lzo_voidp wrkmem )
 {
 #if defined(LZO_OPTIMIZE_GNUC_i386)
@@ -259,7 +260,7 @@ match:
 
 static int
 do_compress    ( const lzo_byte *in , lzo_uint  in_len,
-                       lzo_byte *out, lzo_uint *out_len,
+                       lzo_byte *out, lzo_uintp out_len,
                        lzo_voidp wrkmem )
 {
 #if defined(LZO_OPTIMIZE_GNUC_i386)
@@ -339,9 +340,9 @@ match:
 			assert(ip < ip_end);
 
 			/* 1) store the current literal run */
-			if (ip - ii > 0)
+		    if (pd(ip,ii) > 0)
 			{
-				lzo_uint t = ip - ii;
+			    lzo_uint t = pd(ip,ii);
 
 				if (ip - r1 == MIN_MATCH + 1)
 				{
@@ -433,7 +434,7 @@ match:
 		    	PS || PS || PS || PS || PS || PS || PS || PS ||
 		    	PS || PS || PS || PS || PS || PS)
 #else
-#  error MBITS not yet implemented
+#  error "MBITS not yet implemented"
 #endif
 			{
 			/* we've found a short match */
@@ -599,8 +600,8 @@ match:
 #endif
 
 	/* store the final literal run */
-	if (in_end + DVAL_LEN - ii > 0)
-		op = store_run(op,ii,(lzo_uint)(in_end+DVAL_LEN-ii));
+	if (pd(in_end+DVAL_LEN,ii) > 0)
+		op = store_run(op,ii,pd(in_end+DVAL_LEN,ii));
 
 	*out_len = op - out;
 	return 0;				/* compression went ok */
@@ -613,7 +614,7 @@ match:
 
 LZO_PUBLIC(int)
 lzo1a_compress ( const lzo_byte *in , lzo_uint  in_len,
-                       lzo_byte *out, lzo_uint *out_len,
+                       lzo_byte *out, lzo_uintp out_len,
                        lzo_voidp wrkmem )
 {
 	int r = LZO_E_OK;
@@ -669,5 +670,5 @@ lzo1a_compress ( const lzo_byte *in , lzo_uint  in_len,
 
 
 /*
-vi:ts=4
+vi:ts=4:et
 */
