@@ -2,7 +2,8 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -20,7 +21,7 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
  */
 
 
@@ -103,7 +104,7 @@ extern "C" {
 #define	R0FAST	(R0MAX & ~7)		/* R0MAX aligned to 8 byte boundary */
 
 #if (R0MAX - R0FAST != 7) || ((R0FAST & 7) != 0)
-#  error something went wrong
+#  error "something went wrong"
 #endif
 
 /* 7 special codes from R0FAST+1 .. R0MAX
@@ -139,6 +140,6 @@ RBITS | MBITS  MIN  THR.  MSIZE  MAXS  MINL  MAXL   MAXO  R0MAX R0FAST
 #endif /* already included */
 
 /*
-vi:ts=4
+vi:ts=4:et
 */
 
