@@ -2,7 +2,8 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -20,7 +21,7 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
  */
 
 
@@ -33,7 +34,7 @@
 ************************************************************************/
 
 int _lzo1c_do_compress   ( const lzo_byte *in,  lzo_uint  in_len,
-								 lzo_byte *out, lzo_uint *out_len,
+								 lzo_byte *out, lzo_uintp out_len,
 								 lzo_voidp wrkmem,
 								 lzo_compress_t func )
 {
@@ -148,6 +149,6 @@ void _lzo1c_stats_calc(lzo_stats_t *lzo_stats)
 
 
 /*
-vi:ts=4
+vi:ts=4:et
 */
 
