@@ -2,7 +2,8 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -20,7 +21,7 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
  */
 
 
@@ -64,7 +65,7 @@ lzo_compress_t _lzo1c_get_compress_func(int clevel)
 
 LZO_PUBLIC(int)
 lzo1c_compress ( const lzo_byte *src, lzo_uint  src_len,
-                       lzo_byte *dst, lzo_uint *dst_len,
+                       lzo_byte *dst, lzo_uintp dst_len,
                        lzo_voidp wrkmem,
                        int clevel )
 {
@@ -79,6 +80,6 @@ lzo1c_compress ( const lzo_byte *src, lzo_uint  src_len,
 
 
 /*
-vi:ts=4
+vi:ts=4:et
 */
 
