@@ -2,7 +2,8 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -20,7 +21,7 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
  */
 
 
@@ -73,14 +74,14 @@
 
 LZO_EXTERN(int)
 lzo2a_999_compress_callback ( const lzo_byte *in , lzo_uint  in_len,
-                                    lzo_byte *out, lzo_uint *out_len,
+                                    lzo_byte *out, lzo_uintp out_len,
                                     lzo_voidp wrkmem,
                                     lzo_progress_callback_t cb,
                                     lzo_uint max_chain );
 
 LZO_PUBLIC(int)
 lzo2a_999_compress_callback ( const lzo_byte *in , lzo_uint  in_len,
-                                    lzo_byte *out, lzo_uint *out_len,
+                                    lzo_byte *out, lzo_uintp out_len,
                                     lzo_voidp wrkmem,
                                     lzo_progress_callback_t cb,
                                     lzo_uint max_chain )
@@ -337,7 +338,7 @@ lzo2a_999_compress_callback ( const lzo_byte *in , lzo_uint  in_len,
 
 LZO_PUBLIC(int)
 lzo2a_999_compress  ( const lzo_byte *in , lzo_uint  in_len,
-                            lzo_byte *out, lzo_uint *out_len,
+                            lzo_byte *out, lzo_uintp out_len,
                             lzo_voidp wrkmem )
 {
 	return lzo2a_999_compress_callback(in,in_len,out,out_len,wrkmem,
@@ -348,6 +349,6 @@ lzo2a_999_compress  ( const lzo_byte *in , lzo_uint  in_len,
 #endif /* !defined(LZO_999_UNSUPPORTED) */
 
 /*
-vi:ts=4
+vi:ts=4:et
 */
 
