@@ -2,7 +2,8 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -20,7 +21,7 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
  */
 
 
@@ -68,15 +69,12 @@
 #  define HAVE_MEMSET
 #else
 #  include <sys/types.h>
-#  if defined(STDC_HEADERS)
-#    include <string.h>
-#    include <stdlib.h>
-#  endif
 #  if defined(HAVE_STDDEF_H)
 #    include <stddef.h>
 #  endif
-#  if defined(HAVE_MEMORY_H)
-#    include <memory.h>
+#  if defined(STDC_HEADERS)
+#    include <string.h>
+#    include <stdlib.h>
 #  endif
 #endif
 
@@ -98,8 +96,20 @@
 #include <assert.h>
 
 
+#if !defined(LZO_COMPILE_TIME_ASSERT)
+#  define LZO_COMPILE_TIME_ASSERT(expr) \
+        { typedef int __lzo_compile_time_assert_fail[1 - 2 * !(expr)]; }
+#endif
+
+
 #if !defined(LZO_UNUSED)
-#  define LZO_UNUSED(parm)	(parm = parm)
+#  if 1
+#    define LZO_UNUSED(var)     ((void)&var)
+#  elif 0
+#    define LZO_UNUSED(var)	    { typedef int __lzo_unused[sizeof(var) ? 2 : 1]; }
+#  else
+#    define LZO_UNUSED(parm)	(parm = parm)
+#  endif
 #endif
 
 
@@ -138,16 +148,11 @@
 //
 ************************************************************************/
 
-#if 1
+#if 0
 #  define LZO_BYTE(x)		((unsigned char) (x))
 #else
 #  define LZO_BYTE(x)		((unsigned char) ((x) & 0xff))
 #endif
-#if 0
-#  define LZO_USHORT(x)		((unsigned short) (x))
-#else
-#  define LZO_USHORT(x)		((unsigned short) ((x) & 0xffff))
-#endif
 
 #define LZO_MAX(a,b)		((a) >= (b) ? (a) : (b))
 #define LZO_MIN(a,b)		((a) <= (b) ? (a) : (b))
@@ -186,7 +191,7 @@
 #  elif (UINT_MAX >= LZO_0xffffffffL)
 #    define SIZEOF_UNSIGNED			8
 #  else
-#    error SIZEOF_UNSIGNED
+#    error "SIZEOF_UNSIGNED"
 #  endif
 #endif
 
@@ -196,7 +201,7 @@
 #  elif (ULONG_MAX >= LZO_0xffffffffL)
 #    define SIZEOF_UNSIGNED_LONG	8
 #  else
-#    error SIZEOF_UNSIGNED_LONG
+#    error "SIZEOF_UNSIGNED_LONG"
 #  endif
 #endif
 
@@ -403,6 +408,6 @@ __LZO_EXTERN_C const lzo_uint32 _lzo_crc32_table[256];
 #endif /* already included */
 
 /*
-vi:ts=4
+vi:ts=4:et
 */
 
