@@ -2,7 +2,8 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -20,15 +21,13 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
  */
 
 
 #include "lzo_conf.h"
 #include "lzo_util.h"
 
-#include <stdio.h>
-
 
 #if 0
 #  define IS_SIGNED(type)		(((type) (1ul << (8 * sizeof(type) - 1))) < 0)
@@ -38,6 +37,8 @@
 #  define IS_UNSIGNED(type)		(((type) (-1)) > ((type) 0))
 #endif
 
+#define IS_POWER_OF_2(x)		(((x) & ((x) - 1)) == 0)
+
 
 /***********************************************************************
 // Runtime check of the assumptions about the size of builtin types,
@@ -54,6 +55,7 @@ static lzo_bool strength_reduce_bug(int *);	/* avoid inlining */
 
 
 #if 0 || defined(LZO_DEBUG)
+#include <stdio.h>
 static lzo_bool __lzo_assert_fail(const char *s, unsigned line)
 {
 #if defined(__palmos__)
@@ -69,6 +71,14 @@ static lzo_bool __lzo_assert_fail(const char *s, unsigned line)
 #endif
 
 
+#undef COMPILE_TIME_ASSERT
+#if 0
+#  define COMPILE_TIME_ASSERT(expr)     r &= __lzo_assert(expr)
+#else
+#  define COMPILE_TIME_ASSERT(expr)     LZO_COMPILE_TIME_ASSERT(expr)
+#endif
+
+
 /***********************************************************************
 // The next two functions should get completely optimized out of existance.
 // Some assertions are redundant - but included for clarity.
@@ -76,70 +86,93 @@ static lzo_bool __lzo_assert_fail(const char *s, unsigned line)
 
 static lzo_bool basic_integral_check(void)
 {
-	lzo_bool r = 1;
-	lzo_bool sanity;
+    lzo_bool r = 1;
 
 	/* paranoia */
-	r &= __lzo_assert(CHAR_BIT == 8);
-	r &= __lzo_assert(sizeof(char) == 1);
-	r &= __lzo_assert(sizeof(short) >= 2);
-	r &= __lzo_assert(sizeof(long) >= 4);
-	r &= __lzo_assert(sizeof(int) >= sizeof(short));
-	r &= __lzo_assert(sizeof(long) >= sizeof(int));
+	COMPILE_TIME_ASSERT(CHAR_BIT == 8);
+	COMPILE_TIME_ASSERT(sizeof(char) == 1);
+	COMPILE_TIME_ASSERT(sizeof(short) >= 2);
+	COMPILE_TIME_ASSERT(sizeof(long) >= 4);
+	COMPILE_TIME_ASSERT(sizeof(int) >= sizeof(short));
+	COMPILE_TIME_ASSERT(sizeof(long) >= sizeof(int));
 
-	r &= __lzo_assert(sizeof(lzo_uint32) >= 4);
-	r &= __lzo_assert(sizeof(lzo_uint32) >= sizeof(unsigned));
+	COMPILE_TIME_ASSERT(sizeof(lzo_uint) == sizeof(lzo_int));
+	COMPILE_TIME_ASSERT(sizeof(lzo_uint32) == sizeof(lzo_int32));
+
+    COMPILE_TIME_ASSERT(sizeof(lzo_uint32) >= 4);
+	COMPILE_TIME_ASSERT(sizeof(lzo_uint32) >= sizeof(unsigned));
 #if defined(__LZO_STRICT_16BIT)
-	r &= __lzo_assert(sizeof(lzo_uint) == 2);
+	COMPILE_TIME_ASSERT(sizeof(lzo_uint) == 2);
 #else
-	r &= __lzo_assert(sizeof(lzo_uint) >= 4);
-	r &= __lzo_assert(sizeof(lzo_uint) >= sizeof(unsigned));
+	COMPILE_TIME_ASSERT(sizeof(lzo_uint) >= 4);
+	COMPILE_TIME_ASSERT(sizeof(lzo_uint) >= sizeof(unsigned));
+#endif
+
+	/* paranoia - check <limits.h> header */
+#if (USHRT_MAX == 65535u)
+	COMPILE_TIME_ASSERT(sizeof(short) == 2);
+#elif (USHRT_MAX == LZO_0xffffffffL)
+	COMPILE_TIME_ASSERT(sizeof(short) == 4);
+#elif (USHRT_MAX >= LZO_0xffffffffL)
+	COMPILE_TIME_ASSERT(sizeof(short) > 4);
+#endif
+#if (UINT_MAX == 65535u)
+	COMPILE_TIME_ASSERT(sizeof(int) == 2);
+#elif (UINT_MAX == LZO_0xffffffffL)
+	COMPILE_TIME_ASSERT(sizeof(int) == 4);
+#elif (UINT_MAX >= LZO_0xffffffffL)
+	COMPILE_TIME_ASSERT(sizeof(int) > 4);
+#endif
+#if (ULONG_MAX == 65535ul)
+	COMPILE_TIME_ASSERT(sizeof(long) == 2);
+#elif (ULONG_MAX == LZO_0xffffffffL)
+	COMPILE_TIME_ASSERT(sizeof(long) == 4);
+#elif (ULONG_MAX >= LZO_0xffffffffL)
+	COMPILE_TIME_ASSERT(sizeof(long) > 4);
 #endif
 
 #if defined(SIZEOF_UNSIGNED)
-	r &= __lzo_assert(SIZEOF_UNSIGNED == sizeof(unsigned));
+	COMPILE_TIME_ASSERT(SIZEOF_UNSIGNED == sizeof(unsigned));
 #endif
 #if defined(SIZEOF_UNSIGNED_LONG)
-	r &= __lzo_assert(SIZEOF_UNSIGNED_LONG == sizeof(unsigned long));
+	COMPILE_TIME_ASSERT(SIZEOF_UNSIGNED_LONG == sizeof(unsigned long));
 #endif
 #if defined(SIZEOF_UNSIGNED_SHORT)
-	r &= __lzo_assert(SIZEOF_UNSIGNED_SHORT == sizeof(unsigned short));
+	COMPILE_TIME_ASSERT(SIZEOF_UNSIGNED_SHORT == sizeof(unsigned short));
 #endif
 #if !defined(__LZO_IN_MINILZO)
 #if defined(SIZEOF_SIZE_T)
-	r &= __lzo_assert(SIZEOF_SIZE_T == sizeof(size_t));
+	COMPILE_TIME_ASSERT(SIZEOF_SIZE_T == sizeof(size_t));
 #endif
 #endif
 
 	/* assert the signedness of our integral types */
-	sanity = IS_UNSIGNED(unsigned short) && IS_UNSIGNED(unsigned) &&
-	         IS_UNSIGNED(unsigned long) &&
-	         IS_SIGNED(short) && IS_SIGNED(int) && IS_SIGNED(long);
-	if (sanity)
-	{
-		r &= __lzo_assert(IS_UNSIGNED(lzo_uint32));
-		r &= __lzo_assert(IS_UNSIGNED(lzo_uint));
-		r &= __lzo_assert(IS_SIGNED(lzo_int32));
-		r &= __lzo_assert(IS_SIGNED(lzo_int));
+	COMPILE_TIME_ASSERT(IS_UNSIGNED(unsigned char));
+	COMPILE_TIME_ASSERT(IS_UNSIGNED(unsigned short));
+	COMPILE_TIME_ASSERT(IS_UNSIGNED(unsigned));
+	COMPILE_TIME_ASSERT(IS_UNSIGNED(unsigned long));
+	COMPILE_TIME_ASSERT(IS_SIGNED(short));
+	COMPILE_TIME_ASSERT(IS_SIGNED(int));
+	COMPILE_TIME_ASSERT(IS_SIGNED(long));
 
-		r &= __lzo_assert(INT_MAX    == LZO_STYPE_MAX(sizeof(int)));
-		r &= __lzo_assert(UINT_MAX   == LZO_UTYPE_MAX(sizeof(unsigned)));
-		r &= __lzo_assert(LONG_MAX   == LZO_STYPE_MAX(sizeof(long)));
-		r &= __lzo_assert(ULONG_MAX  == LZO_UTYPE_MAX(sizeof(unsigned long)));
-		r &= __lzo_assert(SHRT_MAX   == LZO_STYPE_MAX(sizeof(short)));
-		r &= __lzo_assert(USHRT_MAX  == LZO_UTYPE_MAX(sizeof(unsigned short)));
-		r &= __lzo_assert(LZO_UINT32_MAX == LZO_UTYPE_MAX(sizeof(lzo_uint32)));
-		r &= __lzo_assert(LZO_UINT_MAX   == LZO_UTYPE_MAX(sizeof(lzo_uint)));
+	COMPILE_TIME_ASSERT(IS_UNSIGNED(lzo_uint32));
+	COMPILE_TIME_ASSERT(IS_UNSIGNED(lzo_uint));
+	COMPILE_TIME_ASSERT(IS_SIGNED(lzo_int32));
+	COMPILE_TIME_ASSERT(IS_SIGNED(lzo_int));
+
+	COMPILE_TIME_ASSERT(INT_MAX    == LZO_STYPE_MAX(sizeof(int)));
+	COMPILE_TIME_ASSERT(UINT_MAX   == LZO_UTYPE_MAX(sizeof(unsigned)));
+	COMPILE_TIME_ASSERT(LONG_MAX   == LZO_STYPE_MAX(sizeof(long)));
+	COMPILE_TIME_ASSERT(ULONG_MAX  == LZO_UTYPE_MAX(sizeof(unsigned long)));
+	COMPILE_TIME_ASSERT(SHRT_MAX   == LZO_STYPE_MAX(sizeof(short)));
+	COMPILE_TIME_ASSERT(USHRT_MAX  == LZO_UTYPE_MAX(sizeof(unsigned short)));
+	COMPILE_TIME_ASSERT(LZO_UINT32_MAX == LZO_UTYPE_MAX(sizeof(lzo_uint32)));
+	COMPILE_TIME_ASSERT(LZO_UINT_MAX   == LZO_UTYPE_MAX(sizeof(lzo_uint)));
 #if !defined(__LZO_IN_MINILZO)
-		r &= __lzo_assert(SIZE_T_MAX     == LZO_UTYPE_MAX(sizeof(size_t)));
+	COMPILE_TIME_ASSERT(SIZE_T_MAX     == LZO_UTYPE_MAX(sizeof(size_t)));
 #endif
-	}
 
-#if 0
-	/* for some reason this fails on a Cray ??? */
 	r &= __lzo_assert(LZO_BYTE(257) == 1);
-	r &= __lzo_assert(LZO_USHORT(65537L) == 1);
-#endif
 
 	return r;
 }
@@ -148,40 +181,39 @@ static lzo_bool basic_integral_check(void)
 static lzo_bool basic_ptr_check(void)
 {
 	lzo_bool r = 1;
-	lzo_bool sanity;
 
-	r &= __lzo_assert(sizeof(char *) >= sizeof(int));
-	r &= __lzo_assert(sizeof(lzo_byte *) >= sizeof(char *));
+	COMPILE_TIME_ASSERT(sizeof(char *) >= sizeof(int));
+	COMPILE_TIME_ASSERT(sizeof(lzo_byte *) >= sizeof(char *));
 
-	r &= __lzo_assert(sizeof(lzo_voidp) == sizeof(lzo_byte *));
-	r &= __lzo_assert(sizeof(lzo_voidp) == sizeof(lzo_voidpp));
-	r &= __lzo_assert(sizeof(lzo_voidp) == sizeof(lzo_bytepp));
-	r &= __lzo_assert(sizeof(lzo_voidp) >= sizeof(lzo_uint));
+	COMPILE_TIME_ASSERT(sizeof(lzo_voidp) == sizeof(lzo_byte *));
+	COMPILE_TIME_ASSERT(sizeof(lzo_voidp) == sizeof(lzo_voidpp));
+	COMPILE_TIME_ASSERT(sizeof(lzo_voidp) == sizeof(lzo_bytepp));
+	COMPILE_TIME_ASSERT(sizeof(lzo_voidp) >= sizeof(lzo_uint));
 
-	r &= __lzo_assert(sizeof(lzo_ptr_t) == sizeof(lzo_voidp));
-	r &= __lzo_assert(sizeof(lzo_ptr_t) >= sizeof(lzo_uint));
+	COMPILE_TIME_ASSERT(sizeof(lzo_ptr_t) == sizeof(lzo_voidp));
+	COMPILE_TIME_ASSERT(sizeof(lzo_ptr_t) == sizeof(lzo_sptr_t));
+	COMPILE_TIME_ASSERT(sizeof(lzo_ptr_t) >= sizeof(lzo_uint));
 
-	r &= __lzo_assert(sizeof(lzo_ptrdiff_t) >= 4);
-	r &= __lzo_assert(sizeof(lzo_ptrdiff_t) >= sizeof(ptrdiff_t));
+	COMPILE_TIME_ASSERT(sizeof(lzo_ptrdiff_t) >= 4);
+	COMPILE_TIME_ASSERT(sizeof(lzo_ptrdiff_t) >= sizeof(ptrdiff_t));
+
+	COMPILE_TIME_ASSERT(sizeof(ptrdiff_t) >= sizeof(size_t));
+	COMPILE_TIME_ASSERT(sizeof(lzo_ptrdiff_t) >= sizeof(lzo_uint));
 
 #if defined(SIZEOF_CHAR_P)
-	r &= __lzo_assert(SIZEOF_CHAR_P == sizeof(char *));
+	COMPILE_TIME_ASSERT(SIZEOF_CHAR_P == sizeof(char *));
 #endif
 #if defined(SIZEOF_PTRDIFF_T)
-	r &= __lzo_assert(SIZEOF_PTRDIFF_T == sizeof(ptrdiff_t));
+	COMPILE_TIME_ASSERT(SIZEOF_PTRDIFF_T == sizeof(ptrdiff_t));
 #endif
 
 	/* assert the signedness of our integral types */
-	sanity = IS_UNSIGNED(unsigned short) && IS_UNSIGNED(unsigned) &&
-	         IS_UNSIGNED(unsigned long) &&
-	         IS_SIGNED(short) && IS_SIGNED(int) && IS_SIGNED(long);
-	if (sanity)
-	{
-		r &= __lzo_assert(IS_UNSIGNED(lzo_ptr_t));
-		r &= __lzo_assert(IS_UNSIGNED(lzo_moff_t));
-		r &= __lzo_assert(IS_SIGNED(lzo_ptrdiff_t));
-		r &= __lzo_assert(IS_SIGNED(lzo_sptr_t));
-	}
+	COMPILE_TIME_ASSERT(IS_SIGNED(ptrdiff_t));
+	COMPILE_TIME_ASSERT(IS_UNSIGNED(size_t));
+	COMPILE_TIME_ASSERT(IS_SIGNED(lzo_ptrdiff_t));
+	COMPILE_TIME_ASSERT(IS_SIGNED(lzo_sptr_t));
+	COMPILE_TIME_ASSERT(IS_UNSIGNED(lzo_ptr_t));
+	COMPILE_TIME_ASSERT(IS_UNSIGNED(lzo_moff_t));
 
 	return r;
 }
@@ -195,28 +227,40 @@ static lzo_bool ptr_check(void)
 {
 	lzo_bool r = 1;
 	int i;
-	char _wrkmem[10 * sizeof(lzo_byte *) + sizeof(lzo_align_t)];
-	lzo_byte *wrkmem;
+	char _wrkmem[10 * sizeof(lzo_byte *) + sizeof(lzo_full_align_t)];
+	lzo_bytep wrkmem;
 	lzo_bytepp dict;
-	unsigned char x[4 * sizeof(lzo_align_t)];
+	unsigned char x[4 * sizeof(lzo_full_align_t)];
 	long d;
-	lzo_align_t a;
+	lzo_full_align_t a;
+	lzo_full_align_t u;
 
 	for (i = 0; i < (int) sizeof(x); i++)
 		x[i] = LZO_BYTE(i);
 
-	wrkmem = LZO_PTR_ALIGN_UP((lzo_byte *)_wrkmem,sizeof(lzo_align_t));
+	wrkmem = LZO_PTR_ALIGN_UP((lzo_byte *)_wrkmem,sizeof(lzo_full_align_t));
+
+#if 0
 	dict = (lzo_bytepp) wrkmem;
+#else
+    /* Avoid a compiler warning on architectures that
+     * do not allow unaligned access. */
+    u.a_lzo_bytep = wrkmem; dict = u.a_lzo_bytepp;
+#endif
 
 	d = (long) ((const lzo_bytep) dict - (const lzo_bytep) _wrkmem);
 	r &= __lzo_assert(d >= 0);
-	r &= __lzo_assert(d < (long) sizeof(lzo_align_t));
+	r &= __lzo_assert(d < (long) sizeof(lzo_full_align_t));
+
+	memset(&a,0,sizeof(a));
+	r &= __lzo_assert(a.a_lzo_voidp == NULL);
 
 	memset(&a,0xff,sizeof(a));
 	r &= __lzo_assert(a.a_ushort == USHRT_MAX);
 	r &= __lzo_assert(a.a_uint == UINT_MAX);
 	r &= __lzo_assert(a.a_ulong == ULONG_MAX);
 	r &= __lzo_assert(a.a_lzo_uint == LZO_UINT_MAX);
+	r &= __lzo_assert(a.a_lzo_uint32 == LZO_UINT32_MAX);
 
 	/* sanity check of the memory model */
 	if (r == 1)
@@ -227,9 +271,9 @@ static lzo_bool ptr_check(void)
 
 	/* check BZERO8_PTR and that NULL == 0 */
 	memset(&a,0,sizeof(a));
-	r &= __lzo_assert(a.a_charp == NULL);
+	r &= __lzo_assert(a.a_char_p == NULL);
 	r &= __lzo_assert(a.a_lzo_bytep == NULL);
-	r &= __lzo_assert(NULL == 0);
+	r &= __lzo_assert(NULL == (void *)0);
 	if (r == 1)
 	{
 		for (i = 0; i < 10; i++)
@@ -269,9 +313,18 @@ static lzo_bool ptr_check(void)
 		/* now check that aligned memory access doesn't core dump */
 		if (r == 1)
 		{
-			lzo_uint32 v0 = * (lzo_uint32 *) &x[k];
-			lzo_uint32 v1 = * (lzo_uint32 *) &x[k+n];
-
+            lzo_uint32 v0, v1;
+#if 0
+			v0 = * (lzo_uint32 *) &x[k];
+			v1 = * (lzo_uint32 *) &x[k+n];
+#else
+            /* Avoid compiler warnings on architectures that
+             * do not allow unaligned access. */
+            u.a_uchar_p = &x[k];
+            v0 = *u.a_lzo_uint32_p;
+            u.a_uchar_p = &x[k+n];
+            v1 = *u.a_lzo_uint32_p;
+#endif
 			r &= __lzo_assert(v0 > 0);
 			r &= __lzo_assert(v1 > 0);
 		}
@@ -294,9 +347,14 @@ _lzo_config_check(void)
 		lzo_uint32 a;
 		unsigned short b;
 		lzo_uint32 aa[4];
-		unsigned char x[4*sizeof(lzo_align_t)];
+		unsigned char x[4*sizeof(lzo_full_align_t)];
 	} u;
 
+	/* check that the compiler correctly casts signed to unsigned */
+	COMPILE_TIME_ASSERT( (int) ((unsigned char) ((signed char) -1)) == 255);
+	/* check that the compiler correctly promotes integrals */
+	COMPILE_TIME_ASSERT( (((unsigned char)128) << (int)(8*sizeof(int)-8)) < 0);
+
 #if 0
 	/* paranoia - the following is guaranteed by definition anyway */
 	r &= __lzo_assert((const void *)&u == (const void *)&u.a);
@@ -314,11 +372,6 @@ _lzo_config_check(void)
 	for (i = 0; i < (int) sizeof(u.x); i++)
 		u.x[i] = LZO_BYTE(i);
 
-#if 0
-	/* check if the compiler correctly casts signed to unsigned */
-	r &= __lzo_assert( (int) (unsigned char) ((char) -1) == 255);
-#endif
-
 	/* check LZO_BYTE_ORDER */
 #if defined(LZO_BYTE_ORDER)
 	if (r == 1)
@@ -334,20 +387,20 @@ _lzo_config_check(void)
 		r &= __lzo_assert(a == 0x00010203L);
 		r &= __lzo_assert(b == 0x0001);
 #  else
-#    error invalid LZO_BYTE_ORDER
+#    error "invalid LZO_BYTE_ORDER"
 #  endif
 	}
 #endif
 
 	/* check that unaligned memory access works as expected */
 #if defined(LZO_UNALIGNED_OK_2)
-	r &= __lzo_assert(sizeof(short) == 2);
+	COMPILE_TIME_ASSERT(sizeof(short) == 2);
 	if (r == 1)
 	{
 		unsigned short b[4];
 
-		for (i = 0; i < 4; i++)
-			b[i] = * (const unsigned short *) &u.x[i];
+        for (i = 0; i < 4; i++)
+            b[i] = * (const unsigned short *) &u.x[i];
 
 #  if (LZO_BYTE_ORDER == LZO_LITTLE_ENDIAN)
 		r &= __lzo_assert(b[0] == 0x0100);
@@ -364,7 +417,7 @@ _lzo_config_check(void)
 #endif
 
 #if defined(LZO_UNALIGNED_OK_4)
-	r &= __lzo_assert(sizeof(lzo_uint32) == 4);
+	COMPILE_TIME_ASSERT(sizeof(lzo_uint32) == 4);
 	if (r == 1)
 	{
 		lzo_uint32 a[4];
@@ -387,10 +440,10 @@ _lzo_config_check(void)
 #endif
 
 #if defined(LZO_ALIGNED_OK_4)
-	r &= __lzo_assert(sizeof(lzo_uint32) == 4);
+	COMPILE_TIME_ASSERT(sizeof(lzo_uint32) == 4);
 #endif
 
-	r &= __lzo_assert(lzo_sizeof_dict_t == sizeof(lzo_dict_t));
+	COMPILE_TIME_ASSERT(lzo_sizeof_dict_t == sizeof(lzo_dict_t));
 
 	/* save space and don't require linking in the lzo_adler32() function */
 #if defined(__LZO_IN_MINLZO)
@@ -400,7 +453,7 @@ _lzo_config_check(void)
 		lzo_uint32 adler;
 		adler = lzo_adler32(0, NULL, 0);
 		adler = lzo_adler32(adler, lzo_copyright(), 200);
-		r &= __lzo_assert(adler == 0x7ea34377L);
+		r &= __lzo_assert(adler == 0xc76f1751L);
 	}
 #endif
 
@@ -452,6 +505,9 @@ static lzo_bool strength_reduce_bug(int *x)
 }
 
 
+#undef COMPILE_TIME_ASSERT
+
+
 /***********************************************************************
 //
 ************************************************************************/
@@ -510,5 +566,5 @@ __lzo_init(unsigned v,int s1,int s2,int s3,int s4,int s5,int s6,int s7)
 
 
 /*
-vi:ts=4
+vi:ts=4:et
 */
