@@ -2,7 +2,8 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -20,7 +21,7 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
  */
 
 
@@ -75,14 +76,16 @@ extern "C" {
 ************************************************************************/
 
 /* ptrdiff_t */
-#if (UINT_MAX >= LZO_0xffffffffL)
-   typedef ptrdiff_t        	lzo_ptrdiff_t;
-#else
-   typedef long             	lzo_ptrdiff_t;
+#if !defined(lzo_ptrdiff_t)
+#  if (UINT_MAX >= LZO_0xffffffffL)
+     typedef ptrdiff_t        	lzo_ptrdiff_t;
+#  else
+     typedef long             	lzo_ptrdiff_t;
+#  endif
 #endif
 
 
-/* Unsigned type that has *exactly* the same number of bits as a lzo_voidp */
+/* Integral types that have *exactly* the same number of bits as a lzo_voidp */
 #if !defined(__LZO_HAVE_PTR_T)
 #  if defined(lzo_ptr_t)
 #    define __LZO_HAVE_PTR_T
@@ -130,15 +133,10 @@ extern "C" {
 //
 ************************************************************************/
 
-/* Always use the safe (=integral) version for pointer-comparisions.
- * The compiler should optimize away the additional casts anyway.
+/* Always use the integral version for pointer comparisions.
  *
  * Note that this only works if the representation and ordering
  * of the pointer and the integral is the same (at bit level).
- *
- * Most 16 bit compilers have their own view about pointers -
- * fortunately they don't care about comparing pointers
- * that are pointing to Nirvana.
  */
 
 #if defined(__LZO_DOS16) || defined(__LZO_WIN16)
@@ -158,6 +156,7 @@ extern "C" {
 #define PTR_LT(a,b)			(PTR(a) < PTR(b))
 #define PTR_GE(a,b)			(PTR(a) >= PTR(b))
 #define PTR_DIFF(a,b)		((lzo_ptrdiff_t) (PTR(a) - PTR(b)))
+#define pd(a,b)		        ((lzo_uint) ((a)-(b)))
 
 
 LZO_EXTERN(lzo_ptr_t)
@@ -181,11 +180,18 @@ typedef union
 	ptrdiff_t		a_ptrdiff_t;
 	lzo_ptrdiff_t	a_lzo_ptrdiff_t;
 	lzo_ptr_t		a_lzo_ptr_t;
-	char *			a_charp;
+	lzo_voidp		a_lzo_voidp;
+    void *          a_void_p;
 	lzo_bytep		a_lzo_bytep;
 	lzo_bytepp		a_lzo_bytepp;
+    lzo_uintp       a_lzo_uintp;
+    lzo_uint *      a_lzo_uint_p;
+    lzo_uint32p     a_lzo_uint32p;
+    lzo_uint32 *    a_lzo_uint32_p;
+    unsigned char * a_uchar_p;
+    char *          a_char_p;
 }
-lzo_align_t;
+lzo_full_align_t;
 
 
 
@@ -196,6 +202,6 @@ lzo_align_t;
 #endif /* already included */
 
 /*
-vi:ts=4
+vi:ts=4:et
 */
 
