@@ -2,7 +2,8 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -20,7 +21,7 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
  */
 
 
@@ -54,9 +55,9 @@ const lzo_byte __lzo_copyright[] =
 #else
 	"\n\n\n"
 	"LZO real-time data compression library.\n"
-	"Copyright (C) 1996, 1997, 1998, 1999, 2000 Markus Franz Xaver Johannes Oberhumer\n"
+	"Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002 Markus Franz Xaver Johannes Oberhumer\n"
 	"<markus.oberhumer@jk.uni-linz.ac.at>\n"
-	"http://wildsau.idv.uni-linz.ac.at/mfx/lzo.html\n"
+	"http://www.oberhumer.com/opensource/lzo/\n"
 	"\n"
 	"LZO version: v" LZO_VERSION_STRING ", " LZO_VERSION_DATE "\n"
 	"LZO build date: " __DATE__ " " __TIME__ "\n\n"
@@ -124,7 +125,7 @@ const lzo_byte __lzo_copyright[] =
 	" by Watcom C " _LZO_MEXPAND(__WATCOMC__)
 #endif
 	" $\n"
-	"$Copyright: LZO (C) 1996, 1997, 1998, 1999, 2000 Markus Franz Xaver Johannes Oberhumer $\n";
+	"$Copyright: LZO (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002 Markus Franz Xaver Johannes Oberhumer $\n";
 #endif
 
 LZO_PUBLIC(const lzo_byte *)
@@ -213,5 +214,5 @@ lzo_adler32(lzo_uint32 adler, const lzo_byte *buf, lzo_uint len)
 
 
 /*
-vi:ts=4
+vi:ts=4:et
 */
