@@ -2,7 +2,8 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -20,7 +21,7 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
  */
 
 
@@ -152,7 +153,7 @@ __asm__ __volatile__( \
 
 
 /***********************************************************************
-// rotate (not used at the moment)
+// rotate (currently not used)
 ************************************************************************/
 
 #if 0
@@ -190,5 +191,5 @@ extern __inline__ unsigned short lzo_rotr16(unsigned short value, int shift)
 #endif /* already included */
 
 /*
-vi:ts=4
+vi:ts=4:et
 */
